@@ -5,7 +5,8 @@
      &                  kick_info,formation1,formation2,sigmahold,
      &                  bhspin1,bhspin2,binstate,mergertype,
      &                  jp,tphys,switchedCE,rad,tms,evolve_type,disrupt,
-     &                  lumin,B_0,bacc,tacc,epoch,menv_bpp,renv_bpp)
+     &                  lumin,B_0,bacc,tacc,epoch,menv_bpp,renv_bpp,
+     &                  bkick)
       IMPLICIT NONE
       INCLUDE 'const_bse.h'
 *
@@ -36,6 +37,7 @@
       REAL*8 MENV,RENV,MENVD,RZAMS,vk
       REAL*8 Porbi,Porbf,Mcf,Menvf,qi,qf,G
       REAL*8 kick_info(2,17),fallback,M1i,M2i
+      REAL*8 bkick(20)
       REAL*8 bhspin1,bhspin2
       common /fall/fallback
       INTEGER formation1,formation2
@@ -327,7 +329,7 @@
                endif
                CALL kick(KW1,M_postCE,M1,M2,ECC,SEP_postCE,
      &                   JORB,vk,star1,R2,fallback,sigmahold,
-     &                   kick_info,disrupt)
+     &                   kick_info,disrupt,bkick)
 * Returning variable state to original naming convention
                MF = M_postCE
                SEPF = SEP_postCE
@@ -639,7 +641,7 @@
                endif
                CALL kick(KW1,M_postCE,M1,M2,ECC,SEP_postCE,
      &                   JORB,vk,star1,R2,fallback,sigmahold,
-     &                   kick_info,disrupt)
+     &                   kick_info,disrupt,bkick)
 * Returning variable state to original naming convention
                MF = M_postCE
                SEPF = SEP_postCE
@@ -793,7 +795,7 @@
                endif
                CALL kick(KW2,M_postCE,M2,M1,ECC,SEP_postCE,
      &                   JORB,vk,star2,R1,fallback,sigmahold,
-     &                   kick_info,disrupt)
+     &                   kick_info,disrupt,bkick)
 * Returning variable state to original naming convention
                MF = M_postCE
                SEPF = SEP_postCE
@@ -1020,7 +1022,7 @@
                    endif
             endif
             CALL kick(KW,MF,M1,0.d0,0.d0,-1.d0,0.d0,vk,star1,
-     &                0.d0,fallback,sigmahold,kick_info,disrupt)
+     &                0.d0,fallback,sigmahold,kick_info,disrupt,bkick)
             if(output) write(*,*)'coel 2 6:',KW,M1,M01,R1,MENV,RENV
          ENDIF
          JSPIN1 = OORB*(K21*R1*R1*(M1-MC1)+K3*RC1*RC1*MC1)
