@@ -533,10 +533,8 @@ C      if(mt0.gt.100.d0) mt = 100.d0
 * Use NS/BH masses given by Belczynski+08. PK.
 *
                      !First calculate the proto-core mass
-                     if(ecsn.gt.0.d0.and.mcbagb.le.ecsn)then
-                        mcx = 1.38d0
-                     elseif(ecsn.eq.0.d0.and.mcbagb.le.2.25d0)then !this should be ecsn, unless ecsn=0
-*                     if(mcbagb.le.2.35d0)then
+                     if(ecsn.gt.0.d0.and.mcbagb.le.ecsn.and.
+     &                    mcbagb.ge.ecsn_mlow)then
                         mcx = 1.38d0
 *                     elseif(mc.lt.4.29d0)then
                      elseif(mc.lt.4.82d0)then
@@ -579,15 +577,12 @@ C      if(mt0.gt.100.d0) mt = 100.d0
 *
 *                    We use the updated proto-core mass from Giacobbo & Mapelli 2020
                      mcx = 1.1d0
-                     if(ecsn.gt.0.d0.and.mcbagb.le.ecsn)then
-                        mcx = 1.38d0
-                     elseif(ecsn.eq.0.d0.and.mcbagb.le.2.25d0)then !this should be ecsn, unless ecsn=0
-                        mcx = 1.38d0
-                     endif
-                     if(mc.le.2.5d0)then
+                     if(ecsn.gt.0.d0.and.mcbagb.le.ecsn.and.
+     &                    mcbagb.ge.ecsn_mlow)then
+                        mt = 1.38d0   ! ECSN fixed mass, no fallback
+                     elseif(mc.le.2.5d0)then
                         fallback = 0.2d0 / (mt - mcx) 
                         mt = mcx + 0.2d0
-                        if(ecsn.gt.0.d0.and.mcbagb.le.ecsn)mt=mt-0.2d0
                      elseif(mc.le.6.d0)then
                         fallback = (0.286d0*mc - 0.514d0) / (mt - mcx)
                         mt = mcx + 0.286d0*mc - 0.514d0
@@ -629,10 +624,13 @@ C      if(mt0.gt.100.d0) mt = 100.d0
                      elseif(mc.gt.11.d0)then
                         mcx = 1.6d0
                      endif
-                     if(mc.lt.2.5d0)then
+
+                     if(ecsn.gt.0.d0.and.mcbagb.le.ecsn.and.
+     &                    mcbagb.ge.ecsn_mlow)then
+                        mt = 1.38d0   ! ECSN fixed mass, no fallback
+                     elseif(mc.lt.2.5d0)then
                         fallback = 0.2d0 / (mt - mcx) 
                         mt = mcx + 0.2
-                        fallback = 0.d0
                      elseif(mc.lt.3.5d0)then
                         fallback = (0.5d0 * mc - 1.05d0) / (mt - mcx)
                         mt = mcx + 0.5d0 * mc - 1.05d0
@@ -760,7 +758,7 @@ C      if(mt0.gt.100.d0) mt = 100.d0
                            mt = polyfit
                            pisn_track(kidx)=6
                         elseif(mcbagb.gt.61.10d0.and.
-     &                         mcbagb.lt.113.29d0)then
+     &                         mcbagb.lt.124.12d0)then
                            mt = 0.d0
                            kw = 15
                            pisn_track(kidx)=7
@@ -802,6 +800,10 @@ C      if(mt0.gt.100.d0) mt = 100.d0
                         endif
                      endif
                      mt = mrem
+* Store the initial BH mass for calculating the ISCO later
+                     if(Mbh_initial.eq.0)then
+                        Mbh_initial = mt
+                     endif
                   endif
                endif
             endif
@@ -912,9 +914,8 @@ C      if(mt0.gt.100.d0) mt = 100.d0
 * Use NS/BH masses given by Belczynski+08. PK.
 *
                      !First calculate the proto-core mass
-                     if(ecsn.gt.0.d0.and.mc.le.ecsn)then
-                        mcx = 1.38d0
-                     elseif(ecsn.eq.0.d0.and.mc.le.2.25d0)then !this should be ecsn, unless ecsn=0
+                     if(ecsn.gt.0.d0.and.mc.le.ecsn.and.
+     &                    mc.ge.ecsn_mlow)then
                         mcx = 1.38d0
                      elseif(mc.lt.4.82d0)then
                         mcx = 1.5d0
@@ -955,14 +956,12 @@ C      if(mt0.gt.100.d0) mt = 100.d0
 *
 *                    We use the updated proto-core mass from Giacobbo & Mapelli 2020
                      mcx = 1.1d0
-                     if(ecsn.gt.0.d0.and.mc.le.ecsn)then
-                        mcx = 1.38d0
-                     elseif(ecsn.eq.0.d0.and.mc.le.2.25d0)then !this should be ecsn, unless ecsn=0
-                        mcx = 1.38d0
-                     endif
-                     if(mc.le.2.5d0)then
+                     if(ecsn.gt.0.d0.and.mc.le.ecsn.and.
+     &                    mc.ge.ecsn_mlow)then
+                        mt = 1.38d0   ! ECSN fixed mass, no fallback
+                     elseif(mc.le.2.5d0)then
+                        fallback = 0.2d0 / (mt - mcx)
                         mt = mcx + 0.2d0
-                        fallback = 0.d0
                      elseif(mc.le.6.d0)then
                         fallback = (0.286d0*mc - 0.514d0) / (mt - mcx)
                         mt = mcx + 0.286d0*mc - 0.514d0
@@ -1004,9 +1003,13 @@ C      if(mt0.gt.100.d0) mt = 100.d0
                      elseif(mc.gt.11.d0)then
                         mcx = 1.6d0
                      endif
-                     if(mc.lt.2.5d0)then
+
+                     if(ecsn.gt.0.d0.and.mc.le.ecsn.and.
+     &                    mc.ge.ecsn_mlow)then
+                        mt = 1.38d0   ! ECSN fixed mass, no fallback
+                     elseif(mc.lt.2.5d0)then
+                        fallback = 0.2d0 / (mt - mcx)
                         mt = mcx + 0.2
-                        fallback = 0.d0
                      elseif(mc.lt.3.5d0)then
                         fallback = (0.5d0 * mc - 1.05d0) / (mt - mcx)
                         mt = mcx + 0.5d0 * mc - 1.05d0
@@ -1136,7 +1139,7 @@ C      if(mt0.gt.100.d0) mt = 100.d0
                            mt = polyfit
                            pisn_track(kidx)=6
                         elseif(mc.gt.61.10d0.and.
-     &                         mc.lt.113.29d0)then
+     &                         mc.lt.124.12d0)then
                            mt = 0.d0
                            kw = 15
                            pisn_track(kidx)=7
@@ -1177,7 +1180,10 @@ C      if(mt0.gt.100.d0) mt = 100.d0
                         endif
                      endif
                      mt = mrem
-
+* Store the initial BH mass for calculating the ISCO later
+                     if(Mbh_initial.eq.0)then
+                        Mbh_initial = mt
+                     endif
                      endif
                   endif
                endif
@@ -1272,6 +1278,10 @@ C      if(mt0.gt.100.d0) mt = 100.d0
 *        Black hole
 *
          mc = mt
+* Store the initial BH mass for calculating the ISCO later
+         if(Mbh_initial.eq.0)then
+            Mbh_initial = mt
+         endif
          lum = 1.0d-10
          r = 4.24d-06*mt
       endif
